@@ -1,24 +1,24 @@
 /***********************************************************************
-* SPDX-FileCopyrightText: 2003-2004 Max Howell <max.howell@methylblue.com>
-* SPDX-FileCopyrightText: 2008-2009 Martin Sandsmark <martin.sandsmark@kde.org>
-*
-* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-***********************************************************************/
+ * SPDX-FileCopyrightText: 2003-2004 Max Howell <max.howell@methylblue.com>
+ * SPDX-FileCopyrightText: 2008-2009 Martin Sandsmark <martin.sandsmark@kde.org>
+ * SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ ***********************************************************************/
 
-#ifndef Config_H
-#define Config_H
+#pragma once
 
-#include <QStringList>
+#include <QObject>
 #include <QSet>
+#include <QStringList>
 
-
-enum class Dirty
-{
+enum class Dirty {
     Layout = 1,
     AntiAliasing = 2,
     Colors = 3,
-    Font
+    Font,
 };
+Q_DECLARE_METATYPE(Dirty);
 
 namespace Filelight
 {
@@ -30,7 +30,7 @@ public:
     static void read();
     static void write();
 
-    //keep everything positive, avoid using DON'T, NOT or NO
+    // keep everything positive, avoid using DON'T, NOT or NO
 
     static bool scanAcrossMounts;
     static bool scanRemoteMounts;
@@ -46,8 +46,6 @@ public:
 
     static const QSet<QByteArray> remoteFsTypes;
 };
-}
+} // namespace Filelight
 
 using Filelight::Config;
-
-#endif
