@@ -10,8 +10,6 @@
 
 #include <QUrl>
 
-#include <KXmlGuiWindow>
-
 #include "Config.h"
 
 class QLabel;
@@ -66,6 +64,7 @@ public Q_SLOTS:
 
     void updateURL(const QUrl &);
     void rescanSingleDir(const QUrl &) const;
+    void connectMapItem(QObject *mapItem) const;
 
 private:
     void setupActions(QQmlApplicationEngine *engine);
