@@ -2,14 +2,15 @@
 // SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
 #include "posixWalker.h"
+#include <QDebug>
 
 static void outputError(const QByteArray &path)
 {
     /// show error message that stat or opendir may give
 
-#define out(s)                                                                                                         \
-qWarning() << s ": " << path;                                                                                      \
-break
+#define out(s)                                                                                                                                                 \
+    qWarning() << s ": " << path;                                                                                                                              \
+    break
 
     switch (errno) {
     case EACCES:
@@ -95,11 +96,15 @@ void POSIXWalker::next()
             return;
         }
 
-        m_entry.isSkipable = S_ISLNK(statbuf.st_mode) || S_ISCHR(statbuf.st_mode) || S_ISBLK(statbuf.st_mode) ||
-            S_ISFIFO(statbuf.st_mode) || S_ISSOCK(statbuf.st_mode);
+        m_entry.isSkipable =
+            S_ISLNK(statbuf.st_mode) || S_ISCHR(statbuf.st_mode) || S_ISBLK(statbuf.st_mode) || S_ISFIFO(statbuf.st_mode) || S_ISSOCK(statbuf.st_mode);
         m_entry.isDir = S_ISDIR(statbuf.st_mode);
         m_entry.isFile = S_ISREG(statbuf.st_mode);
-        m_entry.size = statbuf.st_blocks * S_BLKSIZE;
+        if (Q_UNLIKELY(statbuf.st_blocks == 0 && statbuf.st_size != 0)) { // some fuse implementations don't return blocks; fall back to size
+            m_entry.size = statbuf.st_size;
+        } else { // otherwise default to the actual size in blocks
+            m_entry.size = statbuf.st_blocks * S_BLKSIZE;
+        }
         break;
     }
 }
